@@ -1,7 +1,7 @@
 /* command.h -- The structures used internally to represent commands, and
    the extern declarations of the functions used to create them. */
 
-/* Copyright (C) 1993-2016 Free Software Foundation, Inc.
+/* Copyright (C) 1993-2022 Free Software Foundation, Inc.
 
    This file is part of GNU Bash, the Bourne Again SHell.
 
@@ -49,7 +49,7 @@ enum r_instruction {
   (ri == r_output_direction || ri == r_err_and_out)
 
 #define OUTPUT_REDIRECT(ri) \
-  (ri == r_output_direction || ri == r_input_output || ri == r_err_and_out || ri == r_append_err_and_out)
+  (ri == r_output_direction || ri == r_input_output || ri == r_err_and_out || ri == r_append_err_and_out || ri == r_output_force)
 
 #define INPUT_REDIRECT(ri) \
   (ri == r_input_direction || ri == r_inputa_direction || ri == r_input_output)
@@ -73,36 +73,37 @@ enum command_type { cm_for, cm_case, cm_while, cm_if, cm_simple, cm_select,
 		    cm_arith, cm_cond, cm_arith_for, cm_subshell, cm_coproc };
 
 /* Possible values for the `flags' field of a WORD_DESC. */
-#define W_HASDOLLAR	0x000001	/* Dollar sign present. */
-#define W_QUOTED	0x000002	/* Some form of quote character is present. */
-#define W_ASSIGNMENT	0x000004	/* This word is a variable assignment. */
-#define W_SPLITSPACE	0x000008	/* Split this word on " " regardless of IFS */
-#define W_NOSPLIT	0x000010	/* Do not perform word splitting on this word because ifs is empty string. */
-#define W_NOGLOB	0x000020	/* Do not perform globbing on this word. */
-#define W_NOSPLIT2	0x000040	/* Don't split word except for $@ expansion (using spaces) because context does not allow it. */
-#define W_TILDEEXP	0x000080	/* Tilde expand this assignment word */
-#define W_DOLLARAT	0x000100	/* $@ and its special handling */
-#define W_DOLLARSTAR	0x000200	/* $* and its special handling */
-#define W_NOCOMSUB	0x000400	/* Don't perform command substitution on this word */
-#define W_ASSIGNRHS	0x000800	/* Word is rhs of an assignment statement */
-#define W_NOTILDE	0x001000	/* Don't perform tilde expansion on this word */
-#define W_ITILDE	0x002000	/* Internal flag for word expansion */
-#define W_NOEXPAND	0x004000	/* Don't expand at all -- do quote removal */
-#define W_COMPASSIGN	0x008000	/* Compound assignment */
-#define W_ASSNBLTIN	0x010000	/* word is a builtin command that takes assignments */
-#define W_ASSIGNARG	0x020000	/* word is assignment argument to command */
-#define W_HASQUOTEDNULL	0x040000	/* word contains a quoted null character */
-#define W_DQUOTE	0x080000	/* word should be treated as if double-quoted */
-#define W_NOPROCSUB	0x100000	/* don't perform process substitution */
-#define W_SAWQUOTEDNULL	0x200000	/* word contained a quoted null that was removed */
-#define W_ASSIGNASSOC	0x400000	/* word looks like associative array assignment */
-#define W_ASSIGNARRAY	0x800000	/* word looks like a compound indexed array assignment */
-#define W_ARRAYIND	0x1000000	/* word is an array index being expanded */
-#define W_ASSNGLOBAL	0x2000000	/* word is a global assignment to declare (declare/typeset -g) */
-#define W_NOBRACE	0x4000000	/* Don't perform brace expansion */
-#define W_COMPLETE	0x8000000	/* word is being expanded for completion */
-#define W_CHKLOCAL	0x10000000	/* check for local vars on assignment */
-#define W_NOASSNTILDE	0x20000000	/* don't do tilde expansion like an assignment statement */
+#define W_HASDOLLAR	(1 << 0)	/* Dollar sign present. */
+#define W_QUOTED	(1 << 1)	/* Some form of quote character is present. */
+#define W_ASSIGNMENT	(1 << 2)	/* This word is a variable assignment. */
+#define W_SPLITSPACE	(1 << 3)	/* Split this word on " " regardless of IFS */
+#define W_NOSPLIT	(1 << 4)	/* Do not perform word splitting on this word because ifs is empty string. */
+#define W_NOGLOB	(1 << 5)	/* Do not perform globbing on this word. */
+#define W_NOSPLIT2	(1 << 6)	/* Don't split word except for $@ expansion (using spaces) because context does not allow it. */
+#define W_TILDEEXP	(1 << 7)	/* Tilde expand this assignment word */
+#define W_DOLLARAT	(1 << 8)	/* UNUSED - $@ and its special handling */
+#define W_ARRAYREF	(1 << 9)	/* word is a valid array reference */
+#define W_NOCOMSUB	(1 << 10)	/* Don't perform command substitution on this word */
+#define W_ASSIGNRHS	(1 << 11)	/* Word is rhs of an assignment statement */
+#define W_NOTILDE	(1 << 12)	/* Don't perform tilde expansion on this word */
+#define W_NOASSNTILDE	(1 << 13)	/* don't do tilde expansion like an assignment statement */
+#define W_EXPANDRHS	(1 << 14)	/* Expanding word in ${paramOPword} */
+#define W_COMPASSIGN	(1 << 15)	/* Compound assignment */
+#define W_ASSNBLTIN	(1 << 16)	/* word is a builtin command that takes assignments */
+#define W_ASSIGNARG	(1 << 17)	/* word is assignment argument to command */
+#define W_HASQUOTEDNULL	(1 << 18)	/* word contains a quoted null character */
+#define W_DQUOTE	(1 << 19)	/* UNUSED - word should be treated as if double-quoted */
+#define W_NOPROCSUB	(1 << 20)	/* don't perform process substitution */
+#define W_SAWQUOTEDNULL	(1 << 21)	/* word contained a quoted null that was removed */
+#define W_ASSIGNASSOC	(1 << 22)	/* word looks like associative array assignment */
+#define W_ASSIGNARRAY	(1 << 23)	/* word looks like a compound indexed array assignment */
+#define W_ARRAYIND	(1 << 24)	/* word is an array index being expanded */
+#define W_ASSNGLOBAL	(1 << 25)	/* word is a global assignment to declare (declare/typeset -g) */
+#define W_NOBRACE	(1 << 26)	/* Don't perform brace expansion */
+#define W_COMPLETE	(1 << 27)	/* word is being expanded for completion */
+#define W_CHKLOCAL	(1 << 28)	/* check for local vars on assignment */
+#define W_FORCELOCAL	(1 << 29)	/* force assignments to be to local variables, non-fatal on assignment errors */
+/* UNUSED		(1 << 30)	*/
 
 /* Flags for the `pflags' argument to param_expand() and various
    parameter_brace_expand_xxx functions; also used for string_list_dollar_at */
@@ -111,6 +112,9 @@ enum command_type { cm_for, cm_case, cm_while, cm_if, cm_simple, cm_select,
 #define PF_NOSPLIT2	0x04	/* same as W_NOSPLIT2 */
 #define PF_ASSIGNRHS	0x08	/* same as W_ASSIGNRHS */
 #define PF_COMPLETE	0x10	/* same as W_COMPLETE, sets SX_COMPLETE */
+#define PF_EXPANDRHS	0x20	/* same as W_EXPANDRHS */
+#define PF_ALLINDS	0x40	/* array, act as if [@] was supplied */
+#define PF_BACKQUOTE	0x80	/* differentiate `` from $() for command_substitute */
 
 /* Possible values for subshell_environment */
 #define SUBSHELL_ASYNC	0x01	/* subshell caused by `command &' */
@@ -121,6 +125,7 @@ enum command_type { cm_for, cm_case, cm_while, cm_if, cm_simple, cm_select,
 #define SUBSHELL_PROCSUB 0x20	/* subshell caused by <(command) or >(command) */
 #define SUBSHELL_COPROC	0x40	/* subshell from a coproc pipeline */
 #define SUBSHELL_RESETTRAP 0x80	/* subshell needs to reset trap strings on first call to trap */
+#define SUBSHELL_IGNTRAP 0x100  /* subshell should reset trapped signals from trap_handler */
 
 /* A structure which represents a word. */
 typedef struct word_desc {
@@ -361,6 +366,8 @@ typedef struct subshell_com {
 
 #define COPROC_RUNNING	0x01
 #define COPROC_DEAD	0x02
+#define COPROC_STOPPED	0x04
+#define COPROC_FOREGROUND	0x08	/* why would you want to do this? */
 
 typedef struct coproc {
   char *c_name;
@@ -393,13 +400,13 @@ extern Coproc sh_coproc;
 
 /* Forward declarations of functions declared in copy_cmd.c. */
 
-extern FUNCTION_DEF *copy_function_def_contents __P((FUNCTION_DEF *, FUNCTION_DEF *));
-extern FUNCTION_DEF *copy_function_def __P((FUNCTION_DEF *));
+extern FUNCTION_DEF *copy_function_def_contents (FUNCTION_DEF *, FUNCTION_DEF *);
+extern FUNCTION_DEF *copy_function_def (FUNCTION_DEF *);
 
-extern WORD_DESC *copy_word __P((WORD_DESC *));
-extern WORD_LIST *copy_word_list __P((WORD_LIST *));
-extern REDIRECT *copy_redirect __P((REDIRECT *));
-extern REDIRECT *copy_redirects __P((REDIRECT *));
-extern COMMAND *copy_command __P((COMMAND *));
+extern WORD_DESC *copy_word (WORD_DESC *);
+extern WORD_LIST *copy_word_list (WORD_LIST *);
+extern REDIRECT *copy_redirect (REDIRECT *);
+extern REDIRECT *copy_redirects (REDIRECT *);
+extern COMMAND *copy_command (COMMAND *);
 
 #endif /* _COMMAND_H_ */
